library(dplyr)
library(ggplot2)
library(FDRestimation)
library(ggrepel)
library(hrbrthemes)

load("Volcano/NH_vars_pv_fdr_20230101.rda")

#choose colors
colors=c("gray50","red1")

#Plot
ggplot(data=nh, aes(x=effecsize, y=logP)) + 
  # geom_point(aes(shape=type),size = 4, fill = NA, colour = "gray35") +
  geom_hline(aes(yintercept=7.600902), color="royalblue3",linetype=2,size=3)+
  geom_point(aes(color=BonSig, shape=type), size=6, alpha=0.8) + 
  theme_classic() +
  ylim(0,11)+
  xlim(-0.13,0.13)+
  geom_text_repel(data=nh %>% filter(BonSig=="Yes"),
    aes(label=var),
    box.padding = 1,
    nudge_y = 0,
    segment.ncp = 3,
    force=20,
    max.overlaps = 30,
    size=8.25
    ) +
  scale_color_manual(values=colors)+
  xlab("Effect Size (correlation coefficient)")+
 # ylab(bquote(-log[10](p-value)))+
  ylab(expression(bold(-log[10](p-value))))+
  labs(color="Significant (p-value < 0.0005)", shape="Variable Type")+
  theme(axis.title = element_text(size=30, face="bold"),
        legend.position="bottom",
        legend.title=element_text(size=20), 
        legend.text=element_text(size=20),
        text = element_text(size = 20),
        axis.line = element_line(colour = 'black', size = 2),
        axis.text = element_text(size=25),
        axis.ticks = element_line(color="black",size=4),
        axis.ticks.length = unit(.25, "cm"))+
  annotate("text", x=-0.103, y=7.3, size=7.5, fontface="bold",
           color="royalblue3", label='Bonferonni-adjusted p-value <0.0005')
  
ggsave("nh_PAS_20230104_fig1_volcano(3).png",width = 20, height=10, dpi=600)


